@@ -37,9 +37,12 @@ smoothing = function(frm, xvar, yvar, k, align) {
 }
 
 
-#' Plot a scatter plot with smoothing line, with smoothing window aligned either left, center or right,
-#'       xvar is the continuous independent variable and yvar is the dependent binary variable.
-#'       Smoothing is by a square window of width k
+#' Plot a scatter plot with smoothing line.
+#'
+#' Plot a scatter plot with a smoothing line; the smoothing window is aligned either left, center or right.
+#'
+#' \code{xvar} is the continuous independent variable and \code{yvar} is the dependent binary variable.
+#' Smoothing is by a square window of width \code{k}.
 #'
 #' @param frame data frame to get values from
 #' @param xvar name of the independent column in frame. Assumed to be regularly spaced
@@ -53,14 +56,24 @@ smoothing = function(frm, xvar, yvar, k, align) {
 #'
 #' y = c(1,2,3,4,5,10,15,18,20,25)
 #' x = seq_len(length(y))
-#' df = data.frame(x=x,y=y)
+#' df = data.frame(x=x, y=y, group=x>5)
 #' WVPlots::ConditionalSmoothedScatterPlot(df, "x", "y", NULL,
-#'    title="left smooth, one group", align="left")
+#'    title="left smooth, one groups", align="left")
+#' WVPlots::ConditionalSmoothedScatterPlot(df, "x", "y", "group",
+#'    title="left smooth, two groups", align="left")
 #'
 #' @export
 ConditionalSmoothedScatterPlot = function(frame, xvar, yvar, groupvar, title, ...,
                                           k=3, align="center") {
-  checkArgs(frame=frame,xvar=xvar,yvar=yvar,title=title,...)
+  vlist <- list(xvar = xvar, yvar = yvar)
+  if(!is.null(groupvar)) {
+    vlist$groupvar <- groupvar
+  }
+  frame <- check_frame_args_list(...,
+                               frame = frame,
+                               name_var_list = vlist,
+                               title = title,
+                               funname = "WVPlots::ConditionalSmoothedScatterPlot")
   if(!is.null(groupvar)) {
     if(!isDiscrete(frame[[groupvar]])) {
       stop(paste(groupvar, "should be discrete (factor, character, integer, or logical)"))
